@@ -2,18 +2,20 @@ import os
 import requests
 import yaml
 import json
+import logging
 from .get_bearer_token import get_bearer_token
 
 def push_software(config, fpath, radarType, version_name):
 
-    print('Getting the bearer token...')
+    logging.info("Getting the bearer token...")
+    # print('Getting the bearer token...')
     # check config file type
-    if type(config) is not dict:
-        return "Config file is not a dictionary"
-    else:
-        print('config type: ', type(config))
+    # if type(config) is not dict:
+    #     return "Config file is not a dictionary"
+    # else:
+    #     print('config type: ', type(config))
     # check config file
-    print('config api_url: ', config['api_url'])
+    # print('config api_url: ', config['api_url'])
 
     request_url = config['api_url']
 
@@ -29,9 +31,11 @@ def push_software(config, fpath, radarType, version_name):
 
     # check if can open file path
     if os.path.isfile(fpath):
-        print("ZIP file exists: " + fpath)
+        logging.info("ZIP file exists: " + fpath)
+        # print("ZIP file exists: " + fpath)
     else:
-        print("ZIP not exist: " + fpath)
+        logging.error("ZIP not exist: " + fpath)
+        # print("ZIP not exist: " + fpath)
         return "ZIP not exist: " + fpath
         
     files = {
@@ -43,7 +47,8 @@ def push_software(config, fpath, radarType, version_name):
         'versionName': json.dumps(version_name)
     }
     
-    print('Uploading software...')
+    logging.info("Uploading software...")
+    # print('Uploading software...')
 
     response = requests.post(request_url + '/api/softwares/softwarefiles', headers=headers, data=values, files=files)
     return response.json()
\ No newline at end of file
